%This file replicates the simulation results reported in the paper "Optimal
%Decision Rules for Weak GMM"

clear
load FishMarketData

sims=10^3;

sim_obs_grid=111.*[1 100];
localization_grid=[0 1];

%Set target quantile and parameter space
tau=0.75;

alpha_bounds=[0 30];
beta_bounds=[-10 30];

%Define outcome, endogenous regressor, and exogenous regressors
y=qty;
d=price;
x=ones(length(y),1);

%Choose instruments
z=[mixed stormy];

obs=size(y,1);

moment_dim=size(x,2)+size(z,2);

%Run estimation on underlying data, extracting GMM estimate + weights for
%simulation calibration
Fish_Market_sims_calibrate_smoothed;

data=[y d x z];

True_params=GMM;

GMM_store_big=NaN(2,sims,length(sim_obs_grid),length(localization_grid));
Post_mean_store_big=NaN(2,sims,length(sim_obs_grid),length(localization_grid));
Post_sd_store_big=NaN(2,sims,length(sim_obs_grid),length(localization_grid));
Accept_rate_store=NaN(length(sim_obs_grid),length(localization_grid));
Accept_rate_sd_store=NaN(length(sim_obs_grid),length(localization_grid));
for l1=1:length(sim_obs_grid)
    for l2=1:length(localization_grid)
        [l1 l2]     
       sim_obs=sim_obs_grid(l1);
       if localization_grid(l2)==0
            mixprob=1; %Don't introduce any orthogonality between instruments and other variables
       else
            mixprob=sqrt(111/sim_obs); %Introduce orthogonality between instruments and other variables, corresponding to weakly identified case
       end
       weights=sampling_weights;

       Fish_Market_Simulation_subfile_slice
       
       Accept_rate_store(l1,l2)=mean(accept_store);
       Accept_rate_sd_store(l1,l2)=std(accept_store');
       GMM_store_big(:,:,l1,l2)=GMM_store;
       Post_mean_store_big(:,:,l1,l2)=Post_mean_store;
       Post_sd_store_big(:,:,l1,l2)=Post_sd_store;
       
       save('Fish_simulations.mat')
    end
end