clear

load FishMarketData

alpha_bounds=[0 30];
beta_bounds=[-10 30];
grid_step=0.01;

beta_grid=beta_bounds(1):grid_step:beta_bounds(2);
alpha_grid=alpha_bounds(1):grid_step:alpha_bounds(2);

tau=0.75;

%Define outcome, endogenous regressor, and exogenous regressors
y=qty;
d=price;
x=ones(length(y),1);

%Choose instruments
z=[mixed stormy];

obs=length(y);
moment_dim=size(x,2)+size(z,2);

%create check function
rho=@(tau_temp,u) tau_temp-(u<=0);

%create moment function
gmat=@(tau_temp,beta,alpha) repmat(rho(tau_temp,y-d*beta-x*alpha),1,size(x,2)+size(z,2)).*[x z];

obj=@(theta) CUGMM_loglik(gmat(tau,theta(1),theta(2)));

objstore=NaN(length(beta_grid),length(alpha_grid));
for k1=1:length(beta_grid)
    for k2=1:length(alpha_grid)
        objstore(k1,k2)=obj([beta_grid(k1),alpha_grid(k2)]);
    end
end

GMM_obj=-2*objstore;

figure(1)

subplot(1,3,1)
levels=[5 10 15];
contour(beta_grid,alpha_grid,-GMM_obj',-levels,'LineWidth',2)
ylabel('\alpha','FontSize',16)
xlabel('\beta','FontSize',16)
title('GMM Objective','FontSize',16)

subplot(1,3,2)
plot(alpha_grid,min(GMM_obj),'Linewidth',2)
ylim([0,15])
xlim([min(alpha_grid),max(alpha_grid)])
xlabel('\alpha','FontSize',16)
title('Profiled Objective for \alpha','FontSize',16)

subplot(1,3,3)
plot(beta_grid,min(GMM_obj'),'Linewidth',2)
ylim([0,15])
xlim([min(beta_grid),max(beta_grid)])
xlabel('\beta','FontSize',16)
title('Profiled Objective for \beta','FontSize',16)

figure(2)

subplot(1,3,1)
levels=[5 10 15];
contour(beta_grid,alpha_grid,-GMM_obj',-levels,'LineWidth',2)
ylabel('\alpha','FontSize',16)
xlabel('\beta','FontSize',16)
title('Quasi-Likelihood','FontSize',16)

subplot(1,3,2)
plot(alpha_grid,exp(max(objstore)),'Linewidth',2)
xlim([min(alpha_grid),max(alpha_grid)])
xlabel('\alpha','FontSize',16)
title('Profiled Quasi-Likelihood for \alpha','FontSize',16)

subplot(1,3,3)
plot(beta_grid,exp(max(objstore')),'Linewidth',2)
xlim([min(beta_grid),max(beta_grid)])
xlabel('\beta','FontSize',16)
title('Profiled Quasi-Likelihood for \beta','FontSize',16)